@@ -32,6 +32,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <glib/gi18n-lib.h>
 
 #include <libedata-cal/libedata-cal.h>
 #include <libekolabutil/kolab-util-camel.h>
@@ -137,6 +138,9 @@ e_cal_backend_kolab_todos_factory_init (ECalBackendFactory *factory)
 G_MODULE_EXPORT void
 e_module_load (GTypeModule *type_module)
 {
+	bindtextdomain (GETTEXT_PACKAGE, KOLAB_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	
 	e_cal_backend_kolab_events_factory_register_type (type_module);
 	e_cal_backend_kolab_journal_factory_register_type (type_module);
 	e_cal_backend_kolab_todos_factory_register_type (type_module);
