@@ -53,13 +53,23 @@ util_calendar_create_http_request (KolabSettingsHandler *ksettings,
 	url = camel_kolab_imapx_settings_build_url (settings);
 	camel_url_set_path (url, path);
 
+	/* from the Camel settings, we will get set the configured IMAP
+	 * port, which we need to unset here for HTTP(S). The protocol
+	 * type (SSL/non-SSL) will be reflected in the URL, just we're
+	 * not yet able to set a custom port for HTTP(S). Instead, the
+	 * default ports for this protocol type will be used
+	 */
+	camel_url_set_port (url, 0);
+	
 	passwd = kolab_settings_handler_get_char_field (ksettings,
 	                                                KOLAB_SETTINGS_HANDLER_CHAR_FIELD_KOLAB_USER_PASSWORD,
 	                                                &tmp_err);
 	if (passwd == NULL) {
-		g_warning ("%s()[%u]: no password supplied! (%s)",
-		           __func__, __LINE__, tmp_err->message);
-		g_error_free (tmp_err);
+		g_warning ("%s()[%u]: no password supplied!", __func__, __LINE__);
+		if (tmp_err != NULL) {
+			g_warning ("%s()[%u]: %s", __func__, __LINE__, tmp_err->message);
+			g_error_free (tmp_err);
+		}
 	}
 
 	job = kolab_util_http_job_new ();
@@ -100,7 +110,7 @@ util_calendar_create_pfb_trigger (KolabSettingsHandler *ksettings,
 	                                         path,
 	                                         &tmp_err);
 	g_free (path);
-	if (job == NULL) {
+	if (tmp_err != NULL) {
 		g_propagate_error (error, tmp_err);
 		return NULL;
 	}
@@ -126,7 +136,7 @@ util_calendar_create_xfb_request (KolabSettingsHandler *ksettings,
 	                                         path,
 	                                         &tmp_err);
 	g_free (path);
-	if (job == NULL) {
+	if (tmp_err != NULL) {
 		g_propagate_error (error, tmp_err);
 		g_warning ("%s()[%u] call to kolab_util_calendar_create_http_request() returned NULL!",
 		           __func__, __LINE__);
@@ -206,7 +216,8 @@ kolab_util_calendar_toggle_pfb_trigger (KolabSettingsHandler *ksettings,
 	                                        sourcename,
 	                                        &tmp_err);
 	if (job == NULL) {
-		g_propagate_error (error, tmp_err);
+		if (tmp_err != NULL)
+			g_propagate_error (error, tmp_err);
 		g_warning ("%s()[%u] error: could not create F/B toggle, giving up on %s.",
 		           __func__, __LINE__, sourcename);
 		return FALSE;
@@ -247,7 +258,7 @@ kolab_util_calendar_retrieve_xfb (KolabSettingsHandler *ksettings,
 	job->buffer = g_byte_array_new ();
 	(void)kolab_util_http_get (job, &tmp_err);
 	if (tmp_err != NULL) {
-		/* might happen, perhaps the server did not now about the user. */
+		/* might happen, perhaps the server did not know about the user. */
 		kolab_util_http_job_free (job);
 		g_propagate_error (error, tmp_err);
 		return NULL;
@@ -318,6 +329,7 @@ kolab_util_calendar_store (ECalComponent *ecalcomp,
 		goto cleanup;
 
 	if (do_trigger == TRUE) {
+		kolab_mail_access_password_set_visible (koma, TRUE);
 		(void) kolab_util_calendar_toggle_pfb_trigger (ksettings,
 		                                               foldername,
 		                                               &tmp_err);
@@ -331,6 +343,7 @@ kolab_util_calendar_store (ECalComponent *ecalcomp,
 			g_error_free (tmp_err);
 			tmp_err = NULL;
 		}
+		kolab_mail_access_password_set_visible (koma, FALSE);
 	}
 
  cleanup:
