@@ -29,9 +29,12 @@
 #include <config.h>
 
 #include <glib/gi18n-lib.h>
+#include <glib-object.h>
 
 #include <libekolab/camel-kolab-imapx-store.h>
+
 #include <libekolabutil/kolab-util-error.h>
+#include <libekolabutil/kolab-util-folder.h>
 
 #include "e-kolab-plugin-util.h"
 #include "e-kolab-folder-metadata.h"
@@ -83,6 +86,7 @@ kolab_folder_metadata_ui_foldertype_cb (GtkRadioButton *btn,
 {
 	KolabFolderMetaUIData *uidata = NULL;
 	KolabFolderTypeID foldertype = KOLAB_FOLDER_TYPE_INVAL;
+	GtkWidget *ok_btn = NULL;
 	gpointer type = NULL;
 
 	g_return_if_fail (GTK_IS_RADIO_BUTTON (btn));
@@ -96,7 +100,18 @@ kolab_folder_metadata_ui_foldertype_cb (GtkRadioButton *btn,
 	if (type != NULL)
 		foldertype = GPOINTER_TO_UINT (type);
 
-	g_warning ("%s: folder type id: %i", __func__, foldertype); /* FIXME remove */
+	if ((foldertype > KOLAB_FOLDER_TYPE_INVAL) &&
+	    (foldertype < KOLAB_FOLDER_LAST_TYPE)) {
+		uidata->metadata->foldertype = foldertype;
+		uidata->changed = TRUE;
+	}
+
+	ok_btn = e_kolab_plugin_util_ui_dialog_ref_button (uidata->dialog,
+	                                                   GTK_STOCK_OK,
+	                                                   TRUE);
+	g_return_if_fail (GTK_IS_BUTTON (ok_btn));
+	gtk_widget_set_sensitive (ok_btn, TRUE);
+	g_object_unref (ok_btn);
 }
 
 static void
@@ -104,6 +119,7 @@ kolab_folder_metadata_ui_show_all_cb (GtkToggleButton *btn,
                                       gpointer userdata)
 {
 	KolabFolderMetaUIData *uidata = NULL;
+	GtkWidget *ok_btn = NULL;
 
 	g_return_if_fail (GTK_IS_TOGGLE_BUTTON (btn));
 	g_return_if_fail (userdata != NULL);
@@ -112,7 +128,13 @@ kolab_folder_metadata_ui_show_all_cb (GtkToggleButton *btn,
 	g_return_if_fail (uidata->metadata != NULL);
 
 	uidata->metadata->show_all = !(uidata->metadata->show_all);
-	g_warning ("%s: called", __func__); /* FIXME remove */
+
+	ok_btn = e_kolab_plugin_util_ui_dialog_ref_button (uidata->dialog,
+	                                                   GTK_STOCK_OK,
+	                                                   TRUE);
+	g_return_if_fail (GTK_IS_BUTTON (ok_btn));
+	gtk_widget_set_sensitive (ok_btn, TRUE);
+	g_object_unref (ok_btn);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -132,8 +154,13 @@ e_kolab_folder_metadata_ui_new (void)
 	GtkWidget *btn = NULL;
 	gint ii = 0;
 
+	/* documenting initial settings */
 	uidata->shell_view = NULL;
 	uidata->alert_bar = NULL;
+	uidata->dialog = NULL;
+	uidata->foldername = NULL;
+	uidata->sourcename = NULL;
+	uidata->changed = FALSE;
 
 	uidata->widgets = g_new0 (KolabFolderMetaUIWidgets, 1);
 	uidata->metadata = kolab_data_folder_metadata_new ();
@@ -211,17 +238,19 @@ e_kolab_folder_metadata_ui_new (void)
 	                           "Show all PIM folders in this Kolab account"));
 	gtk_container_add (GTK_CONTAINER (uidata->widgets->chk_btn_show_all), widget);
 
+	/* "show all folders" switch */
+
 	uidata->widgets->chk_btn_show_all_handler_id =
-		g_signal_connect (uidata->widgets->chk_btn_show_all,
+		g_signal_connect (G_OBJECT (uidata->widgets->chk_btn_show_all),
 		                  "toggled",
 		                  G_CALLBACK (kolab_folder_metadata_ui_show_all_cb),
 		                  uidata);
 
 	/* folder type radio buttons */
 
-	for (ii = 0; ii < 5; ii++) {
+	for (ii = 0; ii < KOLAB_FOLDER_META_UI_NUM_TYPES; ii++) {
 		uidata->widgets->radio_btn_handler_id[ii] =
-			g_signal_connect (uidata->widgets->radio_btn_type[ii],
+			g_signal_connect (G_OBJECT (uidata->widgets->radio_btn_type[ii]),
 			                  "toggled",
 			                  G_CALLBACK (kolab_folder_metadata_ui_foldertype_cb),
 			                  uidata);
@@ -259,9 +288,12 @@ void
 e_kolab_folder_metadata_ui_update_from_uidata (KolabFolderMetaUIData *uidata)
 {
 	GtkWidget *widget = NULL;
-	guint handler_id = 0;
+	gulong handler_id = 0;
+	guint ii = 0;
 
 	g_return_if_fail (uidata != NULL);
+	g_return_if_fail (E_IS_SHELL_VIEW (uidata->shell_view));
+	g_return_if_fail (E_IS_ALERT_BAR (uidata->alert_bar));
 	g_return_if_fail (uidata->metadata != NULL);
 	g_return_if_fail (uidata->widgets != NULL);
 
@@ -291,8 +323,45 @@ e_kolab_folder_metadata_ui_update_from_uidata (KolabFolderMetaUIData *uidata)
 	g_signal_handler_unblock (widget, handler_id);
 
 	/* radio button group (current folder type) */
+	for (ii = 0; ii < KOLAB_FOLDER_META_UI_NUM_TYPES; ii++) {
+		g_signal_handler_block (uidata->widgets->radio_btn_type[ii],
+		                        uidata->widgets->radio_btn_handler_id[ii]);
+	}
 
-	g_warning ("%s: FIXME implement me", __func__);
+	switch (uidata->metadata->foldertype) {
+
+	case KOLAB_FOLDER_TYPE_EVENT:
+	case KOLAB_FOLDER_TYPE_EVENT_DEFAULT:
+		ii = 1;
+		break;
+
+	case KOLAB_FOLDER_TYPE_NOTE:
+	case KOLAB_FOLDER_TYPE_NOTE_DEFAULT:
+		ii = 2;
+		break;
+
+	case KOLAB_FOLDER_TYPE_TASK:
+	case KOLAB_FOLDER_TYPE_TASK_DEFAULT:
+		ii = 3;
+		break;
+
+	case KOLAB_FOLDER_TYPE_CONTACT:
+	case KOLAB_FOLDER_TYPE_CONTACT_DEFAULT:
+		ii = 4;
+		break;
+
+	default:
+		/* all else is regarded email */
+		ii = 0;
+	}
+
+	widget = uidata->widgets->radio_btn_type[ii];
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
+
+	for (ii = 0; ii < KOLAB_FOLDER_META_UI_NUM_TYPES; ii++) {
+		g_signal_handler_unblock (uidata->widgets->radio_btn_type[ii],
+		                          uidata->widgets->radio_btn_handler_id[ii]);
+	}
 }
 
 gboolean
@@ -312,25 +381,22 @@ e_kolab_folder_metadata_ui_query_store (KolabFolderMetaUIData *uidata,
 	g_return_val_if_fail (E_IS_SHELL_VIEW (uidata->shell_view), FALSE);
 	g_return_val_if_fail (uidata->metadata != NULL, FALSE);
 
+	/* If we cannot get the store here, it means
+	 * that the store associated with the selected
+	 * path is not a CamelKolabIMAPXStore. This
+	 * should not happen at this point (if the store
+	 * in question is not a Kolab store, then no
+	 * Kolab folder options context menu entry should
+	 * have been shown).
+	 */
 	ok = e_kolab_plugin_util_ui_get_selected_store (uidata->shell_view,
 	                                                &kstore,
-	                                                &selected_path);
-	if (! ok) {
-		/* If we cannot get the store here, it means
-		 * that the store associated with the selected
-		 * path is not a CamelKolabIMAPXStore. This
-		 * should not happen at this point (if the store
-		 * in question is not a Kolab store, then no
-		 * Kolab folder options context menu entry should
-		 * have been shown).
-		 */
-		g_set_error (&tmp_err,
-		             KOLAB_CAMEL_KOLAB_ERROR,
-		             KOLAB_CAMEL_KOLAB_ERROR_GENERIC,
-		             _("Could not get the Kolab store from shell view!"));
+	                                                &selected_path,
+	                                                &tmp_err);
+	if (! ok)
 		goto exit;
-	}
 
+	/* FIXME we have the foldername duped in uidata->foldername */
 	uidata->metadata->foldername = selected_path;
 	uidata->metadata->show_all =
 		camel_kolab_imapx_store_get_show_all_folders (kstore);
@@ -357,6 +423,11 @@ e_kolab_folder_metadata_ui_write_store (KolabFolderMetaUIData *uidata,
                                         GCancellable *cancellable,
                                         GError **err)
 {
+	CamelKolabIMAPXStore *kstore = NULL;
+	gchar *selected_path = NULL;
+	GError *tmp_err = NULL;
+	gboolean ok = FALSE;
+
 	g_return_val_if_fail (uidata != NULL, FALSE);
 	/* cancellable may be NULL */
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
@@ -364,8 +435,39 @@ e_kolab_folder_metadata_ui_write_store (KolabFolderMetaUIData *uidata,
 	g_return_val_if_fail (E_IS_SHELL_VIEW (uidata->shell_view), FALSE);
 	g_return_val_if_fail (uidata->metadata != NULL, FALSE);
 
-	g_warning ("%s: FIXME implement me", __func__);
-	return TRUE;
+	if (! uidata->changed)
+		return TRUE;
+
+	ok = e_kolab_plugin_util_ui_get_selected_store (uidata->shell_view,
+	                                                &kstore,
+	                                                &selected_path,
+	                                                &tmp_err);
+	if (! ok)
+		goto exit;
+
+	if (g_strcmp0 (uidata->foldername, selected_path) != 0)
+		g_warning ("%s()[%u] foldername change: stored '%s' vs. current '%s'",
+		           __func__, __LINE__, uidata->foldername, selected_path);
+
+	ok = camel_kolab_imapx_store_set_folder_type (kstore,
+	                                              uidata->foldername,
+	                                              uidata->metadata->foldertype,
+	                                              cancellable,
+	                                              &tmp_err);
+ exit:
+
+	if (tmp_err != NULL) {
+		g_propagate_error (err, tmp_err);
+		ok = FALSE;
+	}
+
+	if (kstore != NULL)
+		g_object_unref (kstore);
+
+	if (selected_path != NULL)
+		g_free (selected_path);
+
+	return ok;
 }
 
 /*----------------------------------------------------------------------------*/
