@@ -41,6 +41,10 @@
 
 /*----------------------------------------------------------------------------*/
 
+#define KOLAB_FOLDER_META_UI_NUM_TYPES 5
+
+/*----------------------------------------------------------------------------*/
+
 typedef struct _KolabFolderMetaUIWidgets KolabFolderMetaUIWidgets;
 struct _KolabFolderMetaUIWidgets {
 	GtkWidget *container;
@@ -48,29 +52,24 @@ struct _KolabFolderMetaUIWidgets {
 	GtkWidget *frame_type_select;
 	GHashTable *folder_type_map;
 	GSList *radio_group;
-	guint radio_btn_handler_id[5];
-	GtkWidget *radio_btn_type[5];
-#if 0
-	GtkWidget *radio_btn_type_mail;     /* 0 */
-	GtkWidget *radio_btn_type_calendar; /* 1 */
-	GtkWidget *radio_btn_type_memos;    /* 2 */
-	GtkWidget *radio_btn_type_tasks;    /* 3 */
-	GtkWidget *radio_btn_type_contacts; /* 4 */
-#endif
+	gulong radio_btn_handler_id[KOLAB_FOLDER_META_UI_NUM_TYPES];
+	GtkWidget *radio_btn_type[KOLAB_FOLDER_META_UI_NUM_TYPES];
 	/* sub-widgets of container - folder options */
 	GtkWidget *frame_options;
 	GtkWidget *chk_btn_show_all;
-	guint chk_btn_show_all_handler_id;
+	gulong chk_btn_show_all_handler_id;
 };
 
 typedef struct _KolabFolderMetaUIData KolabFolderMetaUIData;
 struct _KolabFolderMetaUIData {
 	EShellView *shell_view;
 	EAlertBar *alert_bar;
+	GtkDialog *dialog;
 	KolabFolderMetaUIWidgets *widgets;
 	KolabDataFolderMetadata *metadata;
 	gchar *foldername;
 	gchar *sourcename;
+	gboolean changed;
 };
 
 /*----------------------------------------------------------------------------*/
