@@ -44,6 +44,10 @@
 
 /*----------------------------------------------------------------------------*/
 
+#define KOLAB_FOLDER_PERM_UI_NUM_PERMS 5
+
+/*----------------------------------------------------------------------------*/
+
 typedef struct _KolabFolderPermUIWidgets KolabFolderPermUIWidgets;
 struct _KolabFolderPermUIWidgets {
 	GtkWidget *container;
@@ -59,21 +63,26 @@ struct _KolabFolderPermUIWidgets {
 	/* sub-widgets of add/edit dialog */
 	GtkWidget *edit_entry_box;
 	GtkWidget *edit_btn_retrieve;
+	GtkWidget *access_rights;
+	GtkWidget *access_rights_lbl;
+	GHashTable *folder_perm_map;
 	GSList *radio_group;
-	GtkWidget *radio_btn_perm_read;
-	GtkWidget *radio_btn_perm_append;
-	GtkWidget *radio_btn_perm_write;
-	GtkWidget *radio_btn_perm_all;
+	gulong radio_btn_handler_id[KOLAB_FOLDER_PERM_UI_NUM_PERMS];
+	GtkWidget *radio_btn_perm[KOLAB_FOLDER_PERM_UI_NUM_PERMS];
+	gchar *radio_btn_perm_lbl[KOLAB_FOLDER_PERM_UI_NUM_PERMS];
 };
 
 typedef struct _KolabFolderPermUIData KolabFolderPermUIData;
 struct _KolabFolderPermUIData {
 	EShellView *shell_view;
 	EAlertBar *alert_bar;
+	GtkDialog *dialog;
 	KolabFolderPermUIWidgets *widgets;
 	KolabDataFolderPermissions *permissions;
 	gchar *foldername;
 	gchar *sourcename;
+	gboolean editing;
+	gboolean changed;
 };
 
 /*----------------------------------------------------------------------------*/
@@ -84,18 +93,6 @@ e_kolab_folder_permissions_ui_new (void);
 void
 e_kolab_folder_permissions_ui_free (KolabFolderPermUIData *uidata);
 
-KolabDataFolderPermissions*
-e_kolab_folder_permissions_read_data_from_folder (const KolabDataImapAccount *account,
-                                                  const gchar *foldername,
-                                                  KolabFolderTypeID foldertype,
-                                                  GError **err);
-gboolean
-e_kolab_folder_permissions_write_data_to_folder (const KolabDataImapAccount *account,
-                                                 const gchar *foldername,
-                                                 KolabFolderTypeID foldertype,
-                                                 const KolabDataFolderPermissions *data,
-                                                 GError **err);
-
 void
 e_kolab_folder_permissions_ui_update_from_uidata (KolabFolderPermUIData *uidata);
 
