@@ -34,6 +34,7 @@
 #include <e-util/e-dialog-utils.h>
 #include <e-util/e-plugin-ui.h>
 
+#include <libevolution-utils/e-alert.h>
 #include <misc/e-alert-bar.h>
 
 #include <libekolab/camel-kolab-imapx-store.h>
@@ -169,13 +170,41 @@ kolab_folder_prop_ui_data_destroy (gpointer data)
 	kolab_folder_prop_ui_data_free ((KolabFolderPropUIData *)data);
 }
 
-static void
-kolab_folder_prop_ui_clear_all_entries (GObject *dialog)
-{
-	g_return_if_fail (dialog != NULL);
+/*----------------------------------------------------------------------------*/
+/* internal statics (non-UI) */
 
-	/* FIXME implement me */
-	g_warning ("%s: FIXME implement me", __func__);
+
+/*----------------------------------------------------------------------------*/
+/* internal statics (UI) */
+
+static void
+kolab_folder_prop_ui_alertbar_visible (KolabFolderPropUIData *uidata,
+                                       gboolean visible)
+{
+	g_return_if_fail (uidata != NULL);
+	g_return_if_fail (uidata->widgets != NULL);
+	g_return_if_fail (E_IS_ALERT_BAR (uidata->widgets->alert_bar));
+
+	if (visible)
+		gtk_widget_show (uidata->widgets->alert_bar);
+	else
+		gtk_widget_hide (uidata->widgets->alert_bar);
+}
+
+static void
+kolab_folder_prop_ui_alertbar_add_error (KolabFolderPropUIData *uidata,
+                                         GError *err)
+{
+	EAlertBar *alert_bar = NULL;
+
+	g_return_if_fail (uidata != NULL);
+	g_return_if_fail (uidata->widgets != NULL);
+
+	alert_bar = E_ALERT_BAR (uidata->widgets->alert_bar);
+	g_return_if_fail (alert_bar);
+
+	e_kolab_plugin_util_ui_alert_bar_add_error (alert_bar,
+	                                            err);
 }
 
 static void
@@ -192,38 +221,78 @@ kolab_folder_prop_ui_notebook_enable (KolabFolderPropUIData *uidata,
 
 static void
 kolab_folder_prop_ui_response_cb (GObject *dialog,
-                                  gint response_id)
+                                  gint response_id,
+                                  gpointer userdata)
 {
+	KolabFolderPropUIData *uidata = NULL;
+	GtkWidget *ok_btn = NULL;
+	GError *tmp_err = NULL;
+	gboolean ok = FALSE;
+
 	g_return_if_fail (dialog != NULL);
+	g_return_if_fail (userdata != NULL);
 
 	if (response_id != GTK_RESPONSE_OK) {
-		kolab_folder_prop_ui_clear_all_entries (dialog);
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		return;
 	}
 
-	/* FIXME implement me */
-	g_warning ("%s: FIXME implement me", __func__);
+	uidata = (KolabFolderPropUIData *) userdata;
+
+	/* we try with folder permissions first, since if it will
+	 * succeed, the following actions may be affected by the
+	 * newly set permissions
+	 */
+
+	ok = e_kolab_folder_permissions_ui_write_store (uidata->perm_ui_data,
+	                                                NULL, /* FIXME add cancellation stack */
+	                                                &tmp_err);
+	if (! ok)
+		goto exit;
+
+	/* Instead of aborting after unsuccessful permission setting,
+	 * should we just dump the error into the EAlertBar and move
+	 * on? Alerts can be stacked in the EAlertBar, so we could
+	 * try whether either operation succeeds, and in the event of
+	 * a double failure just accumulate two errors in the EAlertBar.
+	 * Downside: If there are two errors, the earlier one may not
+	 * be visible unless the latter is closed.
+	 */
+
+	ok = e_kolab_folder_metadata_ui_write_store (uidata->meta_ui_data,
+	                                             NULL, /* FIXME add cancellation stack */
+	                                             &tmp_err);
+ exit:
+	if (tmp_err != NULL) {
+		/* dump GError into EAlertBar */
+		kolab_folder_prop_ui_alertbar_add_error (uidata, tmp_err);
+		g_error_free (tmp_err);
+		/* deactivate OK button (need to cancel or try again) */
+		ok_btn = e_kolab_plugin_util_ui_dialog_ref_button (GTK_DIALOG (uidata->widgets->dialog),
+		                                                   GTK_STOCK_OK,
+		                                                   TRUE);
+		g_return_if_fail (GTK_IS_BUTTON (ok_btn));
+		gtk_widget_set_sensitive (ok_btn, FALSE);
+		g_object_unref (ok_btn);
+		return;
+	}
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
-/*----------------------------------------------------------------------------*/
-/* internal statics (non-UI) */
-
-
-/*----------------------------------------------------------------------------*/
-/* internal statics (UI) */
-
 static KolabFolderPropUIData*
 kolab_folder_prop_ui_dialog_data_new (EShellView *shell_view)
 {
 	KolabFolderPropUIData *uidata = NULL;
 	gchar *foldername = NULL;
 	gchar *sourcename = NULL;
+	GError *tmp_err = NULL;
 
 	g_return_val_if_fail (E_IS_SHELL_VIEW (shell_view), NULL);
 
-	foldername = e_kolab_plugin_util_ui_get_selected_foldername (shell_view);
-	if (foldername == NULL) {
+	foldername = e_kolab_plugin_util_ui_get_selected_foldername (shell_view,
+	                                                             &tmp_err);
+	if (tmp_err != NULL) {
 		/* TODO this should not happen.
 		 *
 		 * If the selected folder is NULL here, it means
@@ -231,8 +300,9 @@ kolab_folder_prop_ui_dialog_data_new (EShellView *shell_view)
 		 * be a context menu entry in this case in the
 		 * first place.
 		 */
-		g_warning ("%s()[%u]: Selected folder is no Kolab folder node",
-		           __func__, __LINE__);
+		g_warning ("%s()[%u]: %s",
+		           __func__, __LINE__, tmp_err->message);
+		g_error_free (tmp_err);
 		return NULL;
 	}
 
@@ -251,7 +321,7 @@ kolab_folder_prop_ui_dialog_data_new (EShellView *shell_view)
 	uidata->widgets->dialog =
 		gtk_dialog_new_with_buttons (_("Edit Kolab Folder Properties..."),
 		                             NULL, /* parent */
-		                             GTK_DIALOG_DESTROY_WITH_PARENT,
+		                             GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_MODAL,
 		                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 		                             GTK_STOCK_OK, GTK_RESPONSE_OK,
 		                             NULL);
@@ -260,12 +330,14 @@ kolab_folder_prop_ui_dialog_data_new (EShellView *shell_view)
 	uidata->meta_ui_data = e_kolab_folder_metadata_ui_new ();
 	uidata->meta_ui_data->shell_view = shell_view;
 	uidata->meta_ui_data->alert_bar = E_ALERT_BAR (uidata->widgets->alert_bar);
+	uidata->meta_ui_data->dialog = GTK_DIALOG (uidata->widgets->dialog);
 	uidata->meta_ui_data->foldername = g_strdup (foldername);
 	uidata->meta_ui_data->sourcename = g_strdup (sourcename);
 
 	uidata->perm_ui_data = e_kolab_folder_permissions_ui_new ();
 	uidata->perm_ui_data->shell_view = shell_view;
 	uidata->perm_ui_data->alert_bar = E_ALERT_BAR (uidata->widgets->alert_bar);
+	uidata->perm_ui_data->dialog = GTK_DIALOG (uidata->widgets->dialog);
 	uidata->perm_ui_data->foldername = g_strdup (foldername);
 	uidata->perm_ui_data->sourcename = g_strdup (sourcename);
 
@@ -344,34 +416,6 @@ kolab_folder_prop_ui_dialog_update_from_uidata (KolabFolderPropUIData *uidata)
 	e_kolab_folder_permissions_ui_update_from_uidata (uidata->perm_ui_data);
 }
 
-static void
-kolab_folder_prop_ui_alertbar_visible (KolabFolderPropUIData *uidata,
-                                       gboolean visible)
-{
-	g_return_if_fail (uidata != NULL);
-	g_return_if_fail (uidata->widgets != NULL);
-	g_return_if_fail (E_IS_ALERT_BAR (uidata->widgets->alert_bar));
-
-	if (visible)
-		gtk_widget_show (uidata->widgets->alert_bar);
-	else
-		gtk_widget_hide (uidata->widgets->alert_bar);
-}
-
-static void
-kolab_folder_prop_ui_alertbar_show_error (KolabFolderPropUIData *uidata,
-                                          GError *err)
-{
-	g_return_if_fail (uidata != NULL);
-	g_return_if_fail (uidata->widgets != NULL);
-	g_return_if_fail (E_IS_ALERT_BAR (uidata->widgets->alert_bar));
-
-	if (err == NULL)
-		return;
-
-	g_warning ("%s: FIXME implement me", __func__);
-}
-
 static gboolean
 kolab_folder_prop_ui_query_metadata (KolabFolderPropUIData *uidata,
                                      GCancellable *cancellable,
@@ -435,7 +479,7 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 
 	/* connect response callback */
 	dialog = G_OBJECT (uidata->widgets->dialog);
-	g_signal_connect (dialog, "response", G_CALLBACK (kolab_folder_prop_ui_response_cb), NULL);
+	g_signal_connect (dialog, "response", G_CALLBACK (kolab_folder_prop_ui_response_cb), uidata);
 	g_object_set_data_full (dialog, E_KOLAB_PROP_DLG_UIDATA, uidata, kolab_folder_prop_ui_data_destroy);
 
 	kolab_folder_prop_ui_notebook_enable (uidata, FALSE);
@@ -473,8 +517,7 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 
  exit:
 	if (tmp_err != NULL) {
-		kolab_folder_prop_ui_alertbar_show_error (uidata,
-		                                          tmp_err);
+		kolab_folder_prop_ui_alertbar_add_error (uidata, tmp_err);
 		g_error_free (tmp_err);
 	}
 }
@@ -521,7 +564,8 @@ kolab_plugin_ui_update_mail_entries_cb (EShellView *shell_view,
 
 	selected_path = e_kolab_plugin_util_ui_get_selected_path (shell_view,
 	                                                          &is_kolab_account_node,
-	                                                          &is_kolab_folder_node);
+	                                                          &is_kolab_folder_node,
+	                                                          NULL);
 	g_free (selected_path);
 
 	shell_window = e_shell_view_get_shell_window (shell_view);
