@@ -36,6 +36,7 @@
 #include <libekolabutil/kolab-util-error.h>
 
 #include "camel-imapx-extd-server.h"
+#include "camel-kolab-imapx-acl.h"
 #include "camel-kolab-imapx-metadata.h"
 #include "camel-kolab-imapx-store.h"
 
@@ -70,6 +71,7 @@ struct _CamelKolabIMAPXStorePrivate {
 	KolabFolderContextID folder_context;
 	gboolean folder_types_do_care[KOLAB_FOLDER_LAST_TYPE];
 	GList *folder_names_do_care;
+	CamelKolabImapxAcl *kacl; /* Kolab acl (mostly identical to IMAPX acl) */
 	CamelKolabImapxMetadata *kmd; /* Kolab metadata (differs from IMAPX metadata!) */
 
 	GList *folder_names_unsubscribe;
@@ -128,6 +130,9 @@ camel_kolab_imapx_store_init (CamelKolabIMAPXStore *self)
 
 	priv->folder_names_do_care = NULL;
 
+	/* acl lookup table (no db yet) */
+	priv->kacl = camel_kolab_imapx_acl_new (FALSE);
+
 	/* metadata db and lookup table */
 	priv->kmd = camel_kolab_imapx_metadata_new ();
 
@@ -169,6 +174,7 @@ camel_kolab_imapx_store_finalize (GObject *object)
 		           __func__, tmp_err->message);
 		g_error_free (tmp_err);
 	}
+	camel_kolab_imapx_acl_free (priv->kacl);
 	camel_kolab_imapx_metadata_free (priv->kmd);
 
 	while (! g_mutex_trylock (&(priv->kolab_finfo_lock)));
@@ -438,6 +444,63 @@ imapx_store_set_foldertype (CamelKolabIMAPXStore *self,
 	return TRUE;
 }
 
+static gboolean
+imapx_store_set_folder_permissions (CamelKolabIMAPXStore *self,
+                                    const gchar *foldername,
+                                    const GList *permissions,
+                                    GCancellable *cancellable,
+                                    GError **err)
+{
+	CamelKolabIMAPXStorePrivate *priv = NULL;
+	CamelIMAPXExtdStore *es = NULL;
+	GError *tmp_err = NULL;
+	gboolean perms_ok = FALSE;
+
+	g_assert (CAMEL_IS_KOLAB_IMAPX_STORE (self));
+	g_assert (foldername != NULL);
+	/* permissions may be NULL */
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	priv = CAMEL_KOLAB_IMAPX_STORE_PRIVATE (self);
+	es = CAMEL_IMAPX_EXTD_STORE (self);
+
+	/* check whether we are online and get server */
+	if (! camel_offline_store_get_online (CAMEL_OFFLINE_STORE (self))) {
+		/* If we're here, we're trying to set the
+		 * permissions of the folder in offline mode -
+		 * to be sure the folder permissions can be set,
+		 * we must be online
+		 */
+		g_set_error (err,
+		             KOLAB_CAMEL_KOLAB_ERROR,
+		             KOLAB_CAMEL_KOLAB_ERROR_SERVER,
+		             _("Must be online to complete this operation"));
+		return FALSE;
+	}
+
+	/* set folder perms on the server */
+	perms_ok = camel_imapx_extd_store_set_acl (es,
+	                                           foldername,
+	                                           permissions,
+	                                           cancellable,
+	                                           &tmp_err);
+	if (! perms_ok) {
+		g_propagate_error (err, tmp_err);
+		return FALSE;
+	}
+
+	/* create kolab "flat" data structure */
+	(void) camel_kolab_imapx_acl_update_from_list (priv->kacl,
+	                                               foldername,
+	                                               permissions,
+	                                               NULL);
+
+	/* persistence to be added here, if needed */
+
+	return TRUE;
+}
+
 static CamelFolderInfo*
 imapx_store_folder_info_build_restricted (CamelKolabIMAPXStore *self,
                                           const CamelFolderInfo *fi,
@@ -984,7 +1047,7 @@ kolab_imapx_store_delete_folder_sync (CamelStore *self,
 	                                 &tmp_err);
 	if (! ok) {
 		g_debug ("%s: removing type annotation for '%s' on server failed: %s",
-		           __func__, foldername, tmp_err->message);
+		         __func__, foldername, tmp_err->message);
 		g_error_free (tmp_err);
 	}
 
@@ -1130,6 +1193,32 @@ kolab_imapx_store_get_folder_type (CamelKolabIMAPXStore *self,
 	return folder_type;
 }
 
+static gboolean
+kolab_imapx_store_set_folder_type (CamelKolabIMAPXStore *self,
+                                   const gchar *foldername,
+                                   KolabFolderTypeID foldertype,
+                                   GCancellable *cancellable,
+                                   GError **err)
+{
+	GError *tmp_err = NULL;
+	gboolean ok = FALSE;
+
+	g_assert (CAMEL_IS_KOLAB_IMAPX_STORE (self));
+	g_assert (foldername != NULL);
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	ok = imapx_store_set_foldertype (self,
+	                                 foldername,
+	                                 foldertype,
+	                                 cancellable,
+	                                 &tmp_err);
+	if (! ok)
+		g_propagate_error (err, tmp_err);
+
+	return ok;
+}
+
 static GList*
 kolab_imapx_store_resect_folder_list (CamelKolabIMAPXStore *self)
 {
@@ -1211,6 +1300,117 @@ kolab_imapx_store_set_show_all_folders (CamelKolabIMAPXStore *self,
 	return ok;
 }
 
+static GList*
+kolab_imapx_store_get_folder_permissions (CamelKolabIMAPXStore *self,
+                                          const gchar *foldername,
+                                          gboolean myrights,
+                                          GCancellable *cancellable,
+                                          GError **err)
+{
+	CamelKolabIMAPXStorePrivate *priv = NULL;
+	CamelImapxAcl *acl = NULL;
+	CamelImapxAclSpec *spec = NULL;
+	CamelImapxAclType type = 0;
+	GList *perms = NULL;
+	GError *tmp_err = NULL;
+	gboolean ok = TRUE;
+
+	g_assert (CAMEL_IS_KOLAB_IMAPX_STORE (self));
+	g_assert (foldername != NULL);
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	priv = CAMEL_KOLAB_IMAPX_STORE_PRIVATE (self);
+
+	g_mutex_lock (&(priv->kolab_finfo_lock));
+
+	/* issue IMAP command */
+
+	if (myrights)
+		type = CAMEL_IMAPX_ACL_TYPE_MYRIGHTS;
+	else
+		type = CAMEL_IMAPX_ACL_TYPE_GENERAL;
+
+	spec = camel_imapx_acl_spec_new (foldername, type);
+	acl = camel_imapx_extd_store_get_acl (CAMEL_IMAPX_EXTD_STORE (self),
+	                                      spec,
+	                                      TRUE, /* resect ACL data */
+	                                      cancellable,
+	                                      &tmp_err);
+	camel_imapx_acl_spec_free (spec);
+	if (tmp_err != NULL)
+		goto exit;
+
+	ok = camel_kolab_imapx_acl_update_from_acl (priv->kacl,
+	                                            acl,
+	                                            &tmp_err);
+	camel_imapx_acl_free (acl);
+	if (! ok)
+		goto exit;
+
+	if (myrights) {
+		CamelImapxAclEntry *entry = NULL;
+		gchar *rights = NULL;
+
+		rights = camel_kolab_imapx_acl_get_myrights (priv->kacl,
+		                                             foldername);
+		/* rights may be NULL */
+		if (rights != NULL) {
+			entry = camel_imapx_acl_entry_new (NULL,
+			                                   rights,
+			                                   NULL);
+			g_free (rights);
+			perms = g_list_prepend (perms, entry);
+		}
+	} else {
+		/* permission list may be empty */
+		perms = camel_kolab_imapx_acl_get_as_list (priv->kacl,
+		                                           foldername);
+	}
+
+ exit:
+
+	if (tmp_err != NULL)
+		g_propagate_error (err, tmp_err);
+
+	g_mutex_unlock (&(priv->kolab_finfo_lock));
+
+	return perms;
+}
+
+static gboolean
+kolab_imapx_store_set_folder_permissions (CamelKolabIMAPXStore *self,
+                                          const gchar *foldername,
+                                          const GList *permissions,
+                                          GCancellable *cancellable,
+                                          GError **err)
+{
+	CamelKolabIMAPXStorePrivate *priv = NULL;
+	GError *tmp_err = NULL;
+	gboolean ok = FALSE;
+
+	g_assert (CAMEL_IS_KOLAB_IMAPX_STORE (self));
+	/* permissions may be NULL (use to delete all permissions) */
+	/* cancellable may be NULL */
+	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
+
+	priv = CAMEL_KOLAB_IMAPX_STORE_PRIVATE (self);
+
+	g_mutex_lock (&(priv->kolab_finfo_lock));
+
+	ok = imapx_store_set_folder_permissions (self,
+	                                         foldername,
+	                                         permissions,
+	                                         cancellable,
+	                                         &tmp_err);
+	if (! ok)
+		g_propagate_error (err, tmp_err);
+
+	g_mutex_unlock (&(priv->kolab_finfo_lock));
+
+	return ok;
+}
+
 /*----------------------------------------------------------------------------*/
 /* interface functions */
 
@@ -1428,10 +1628,13 @@ camel_kolab_imapx_store_class_init (CamelKolabIMAPXStoreClass *klass)
 	klass->get_folder_creation_type = kolab_imapx_store_get_folder_creation_type;
 	klass->set_folder_context = kolab_imapx_store_set_folder_context;
 	klass->get_folder_type = kolab_imapx_store_get_folder_type;
+	klass->set_folder_type = kolab_imapx_store_set_folder_type;
 	klass->get_folder_info_online = kolab_imapx_store_get_folder_info_online;
 	klass->resect_folder_list = kolab_imapx_store_resect_folder_list;
 	klass->get_show_all_folders = kolab_imapx_store_get_show_all_folders;
 	klass->set_show_all_folders = kolab_imapx_store_set_show_all_folders;
+	klass->get_folder_permissions = kolab_imapx_store_get_folder_permissions;
+	klass->set_folder_permissions = kolab_imapx_store_set_folder_permissions;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -1503,6 +1706,27 @@ camel_kolab_imapx_store_get_folder_type (CamelKolabIMAPXStore *self,
 	return foldertype;
 }
 
+gboolean
+camel_kolab_imapx_store_set_folder_type (CamelKolabIMAPXStore *self,
+                                         const gchar *foldername,
+                                         KolabFolderTypeID foldertype,
+                                         GCancellable *cancellable,
+                                         GError **err)
+{
+	CamelKolabIMAPXStoreClass *klass = NULL;
+	gboolean ok = FALSE;
+
+	g_return_val_if_fail (CAMEL_IS_KOLAB_IMAPX_STORE (self), KOLAB_FOLDER_TYPE_INVAL);
+
+	klass = CAMEL_KOLAB_IMAPX_STORE_GET_CLASS (self);
+	ok = klass->set_folder_type (self,
+	                             foldername,
+	                             foldertype,
+	                             cancellable,
+	                             err);
+	return ok;
+}
+
 CamelFolderInfo*
 camel_kolab_imapx_store_get_folder_info_online (CamelKolabIMAPXStore *self,
                                                 const gchar *top,
@@ -1571,5 +1795,47 @@ camel_kolab_imapx_store_set_show_all_folders (CamelKolabIMAPXStore *self,
 	return ok;
 }
 
+GList*
+camel_kolab_imapx_store_get_folder_permissions (CamelKolabIMAPXStore *self,
+                                                const gchar *foldername,
+                                                gboolean myrights,
+                                                GCancellable *cancellable,
+                                                GError **err)
+{
+	CamelKolabIMAPXStoreClass *klass = NULL;
+	GList *perms = NULL;
+
+	g_return_val_if_fail (CAMEL_IS_KOLAB_IMAPX_STORE (self), FALSE);
+
+	klass = CAMEL_KOLAB_IMAPX_STORE_GET_CLASS (self);
+	perms = klass->get_folder_permissions (self,
+	                                       foldername,
+	                                       myrights,
+	                                       cancellable,
+	                                       err);
+	return perms;
+}
+
+gboolean
+camel_kolab_imapx_store_set_folder_permissions (CamelKolabIMAPXStore *self,
+                                                const gchar *foldername,
+                                                const GList *permissions,
+                                                GCancellable *cancellable,
+                                                GError **err)
+{
+	CamelKolabIMAPXStoreClass *klass = NULL;
+	gboolean ok = FALSE;
+
+	g_return_val_if_fail (CAMEL_IS_KOLAB_IMAPX_STORE (self), FALSE);
+
+	klass = CAMEL_KOLAB_IMAPX_STORE_GET_CLASS (self);
+	ok = klass->set_folder_permissions (self,
+	                                    foldername,
+	                                    permissions,
+	                                    cancellable,
+	                                    err);
+	return ok;
+}
+
 /*----------------------------------------------------------------------------*/
 /*----------------------------------------------------------------------------*/
