@@ -89,6 +89,12 @@ struct _CamelKolabIMAPXStoreClass {
 	                                      GCancellable *cancellable,
 	                                      GError **err);
 
+	gboolean (*set_folder_type) (CamelKolabIMAPXStore *self,
+	                             const gchar *foldername,
+	                             KolabFolderTypeID foldertype,
+	                             GCancellable *cancellable,
+	                             GError **err);
+
 	CamelFolderInfo* (*get_folder_info_online) (CamelKolabIMAPXStore *self,
 	                                            const gchar *top,
 	                                            CamelStoreGetFolderInfoFlags flags,
@@ -103,11 +109,25 @@ struct _CamelKolabIMAPXStoreClass {
 	                                  gboolean show_all,
 	                                  GCancellable *cancellable,
 	                                  GError **err);
+
+	GList* (*get_folder_permissions) (CamelKolabIMAPXStore *self,
+	                                  const gchar *foldername,
+	                                  gboolean myrights,
+	                                  GCancellable *cancellable,
+	                                  GError **err);
+
+	gboolean (*set_folder_permissions) (CamelKolabIMAPXStore *self,
+	                                    const gchar *foldername,
+	                                    const GList *permissions,
+	                                    GCancellable *cancellable,
+	                                    GError **err);
 };
 
 GType camel_kolab_imapx_store_get_type (void);
 
-/* Kolab extension: set/get type for newly created folders */
+/* Kolab extensions */
+
+/* metadata: set/get type for newly created folders */
 gboolean
 camel_kolab_imapx_store_set_folder_creation_type (CamelKolabIMAPXStore *self,
                                                   KolabFolderTypeID type_id,
@@ -116,12 +136,12 @@ camel_kolab_imapx_store_set_folder_creation_type (CamelKolabIMAPXStore *self,
 KolabFolderTypeID
 camel_kolab_imapx_store_get_folder_creation_type (CamelKolabIMAPXStore *self);
 
-/* Kolab extension: set the folder context (email, calendar, contacts (defaults to email)) */
+/* metadata: set the folder context (email, calendar, contacts (defaults to email)) */
 gboolean
 camel_kolab_imapx_store_set_folder_context (CamelKolabIMAPXStore *self,
                                             KolabFolderContextID context);
 
-/* Kolab extension: get the folder type id */
+/* metadata: get the folder type id */
 KolabFolderTypeID
 camel_kolab_imapx_store_get_folder_type (CamelKolabIMAPXStore *self,
                                          const gchar *foldername,
@@ -129,28 +149,52 @@ camel_kolab_imapx_store_get_folder_type (CamelKolabIMAPXStore *self,
                                          GCancellable *cancellable,
                                          GError **err);
 
-/* Kolab extension */
+/* metadata: set the folder type id */
+gboolean
+camel_kolab_imapx_store_set_folder_type (CamelKolabIMAPXStore *self,
+                                         const gchar *foldername,
+                                         KolabFolderTypeID foldertype,
+                                         GCancellable *cancellable,
+                                         GError **err);
+
+/* online-query the folder info (no update of persistent DBs) */
 CamelFolderInfo*
 camel_kolab_imapx_store_get_folder_info_online (CamelKolabIMAPXStore *self,
                                                 const gchar *top,
                                                 CamelStoreGetFolderInfoFlags flags,
                                                 GCancellable *cancellable,
                                                 GError **err);
-/* Kolab extension */
+/* rip out list of foldernames */
 GList*
 camel_kolab_imapx_store_resect_folder_list (CamelKolabIMAPXStore *self);
 
-/* Kolab extension */
+/* metadata: whether all folders are shown or non-PIM-folders are hidden */
 gboolean
 camel_kolab_imapx_store_get_show_all_folders (CamelKolabIMAPXStore *self);
 
-/* Kolab extension */
+/* metadata: whether or not to unhide PIM-folders in mail context */
 gboolean
 camel_kolab_imapx_store_set_show_all_folders (CamelKolabIMAPXStore *self,
                                               gboolean show_all,
                                               GCancellable *cancellable,
                                               GError **err);
 
+/* acl: get the permissions for a folder */
+GList*
+camel_kolab_imapx_store_get_folder_permissions (CamelKolabIMAPXStore *self,
+                                                const gchar *foldername,
+                                                gboolean myrights,
+                                                GCancellable *cancellable,
+                                                GError **err);
+
+/* acl: set (update) the permissions for a folder */
+gboolean
+camel_kolab_imapx_store_set_folder_permissions (CamelKolabIMAPXStore *self,
+                                                const gchar *foldername,
+                                                const GList *permissions,
+                                                GCancellable *cancellable,
+                                                GError **err);
+
 G_END_DECLS
 
 /*----------------------------------------------------------------------------*/
