@@ -100,9 +100,9 @@ G_DEFINE_TYPE (KolabMailSideCache, kolab_mail_side_cache, G_TYPE_OBJECT)
 /* SQLite helpers */
 
 static gboolean
-kolab_mail_side_cache_sql_table_create (KolabUtilSqliteDb *kdb,
-                                        const gchar *tblname,
-                                        GError **err)
+mail_side_cache_sql_table_create (KolabUtilSqliteDb *kdb,
+                                  const gchar *tblname,
+                                  GError **err)
 {
 	gchar* sql_str = NULL;
 	gboolean ok = FALSE;
@@ -135,8 +135,8 @@ kolab_mail_side_cache_sql_table_create (KolabUtilSqliteDb *kdb,
 }
 
 static gchar*
-kolab_mail_side_cache_sql_new_tblname (const gchar *uid,
-                                       const gchar *foldername)
+mail_side_cache_sql_new_tblname (const gchar *uid,
+                                 const gchar *foldername)
 {
 	gchar *tblname = NULL;
 
@@ -148,10 +148,10 @@ kolab_mail_side_cache_sql_new_tblname (const gchar *uid,
 }
 
 static gboolean
-kolab_mail_side_cache_sql_delete_by_uid (KolabUtilSqliteDb *kdb,
-                                         const gchar *uid,
-                                         const gchar *foldername,
-                                         GError **err)
+mail_side_cache_sql_delete_by_uid (KolabUtilSqliteDb *kdb,
+                                   const gchar *uid,
+                                   const gchar *foldername,
+                                   GError **err)
 {
 	gchar *tblname = NULL;
 	gboolean exists = FALSE;
@@ -164,7 +164,7 @@ kolab_mail_side_cache_sql_delete_by_uid (KolabUtilSqliteDb *kdb,
 	g_assert (foldername != NULL);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
-	tblname = kolab_mail_side_cache_sql_new_tblname (uid, foldername);
+	tblname = mail_side_cache_sql_new_tblname (uid, foldername);
 
 	/* check if object exists */
 	exists = kolab_util_sqlite_table_exists (kdb, tblname, &tmp_err);
@@ -191,9 +191,9 @@ kolab_mail_side_cache_sql_delete_by_uid (KolabUtilSqliteDb *kdb,
 }
 
 static gboolean
-kolab_mail_side_cache_sql_delete_folder (KolabUtilSqliteDb *kdb,
-                                         const gchar *foldername,
-                                         GError **err)
+mail_side_cache_sql_delete_folder (KolabUtilSqliteDb *kdb,
+                                   const gchar *foldername,
+                                   GError **err)
 {
 	(void)kdb;
 	(void)foldername;
@@ -210,10 +210,10 @@ kolab_mail_side_cache_sql_delete_folder (KolabUtilSqliteDb *kdb,
 }
 
 static Kolab_conv_mail*
-kolab_mail_side_cache_sql_query_object (KolabUtilSqliteDb *kdb,
-                                        const gchar *uid,
-                                        const gchar *foldername,
-                                        GError **err)
+mail_side_cache_sql_query_object (KolabUtilSqliteDb *kdb,
+                                  const gchar *uid,
+                                  const gchar *foldername,
+                                  GError **err)
 {
 	Kolab_conv_mail *kconvmail = NULL;
 	gchar *tblname = NULL;
@@ -231,7 +231,7 @@ kolab_mail_side_cache_sql_query_object (KolabUtilSqliteDb *kdb,
 	g_assert (foldername != NULL);
 	g_return_val_if_fail (err == NULL || *err == NULL, NULL);
 
-	tblname = kolab_mail_side_cache_sql_new_tblname (uid, foldername);
+	tblname = mail_side_cache_sql_new_tblname (uid, foldername);
 
 	/* check if object exists */
 	exists = kolab_util_sqlite_table_exists (kdb, tblname, &tmp_err);
@@ -390,11 +390,11 @@ kolab_mail_side_cache_sql_query_object (KolabUtilSqliteDb *kdb,
 }
 
 static gboolean
-kolab_mail_side_cache_sql_store_object (KolabUtilSqliteDb *kdb,
-                                        const Kolab_conv_mail *kconvmail,
-                                        const gchar *uid,
-                                        const gchar *foldername,
-                                        GError **err)
+mail_side_cache_sql_store_object (KolabUtilSqliteDb *kdb,
+                                  const Kolab_conv_mail *kconvmail,
+                                  const gchar *uid,
+                                  const gchar *foldername,
+                                  GError **err)
 {
 	guint ii = 0;
 	gchar *tblname = NULL;
@@ -409,7 +409,7 @@ kolab_mail_side_cache_sql_store_object (KolabUtilSqliteDb *kdb,
 	g_assert (foldername != NULL);
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
-	tblname = kolab_mail_side_cache_sql_new_tblname (uid, foldername);
+	tblname = mail_side_cache_sql_new_tblname (uid, foldername);
 
 	/* check if object exists */
 	exists = kolab_util_sqlite_table_exists (kdb, tblname, &tmp_err);
@@ -431,7 +431,7 @@ kolab_mail_side_cache_sql_store_object (KolabUtilSqliteDb *kdb,
 		}
 	}
 
-	ok = kolab_mail_side_cache_sql_table_create (kdb, tblname, &tmp_err);
+	ok = mail_side_cache_sql_table_create (kdb, tblname, &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
 		g_free (tblname);
@@ -687,9 +687,9 @@ kolab_mail_side_cache_delete_folder (KolabMailSideCache *self,
 
 	g_assert (priv->is_up == TRUE);
 
-	ok = kolab_mail_side_cache_sql_delete_folder (priv->kdb,
-	                                              foldername,
-	                                              &tmp_err);
+	ok = mail_side_cache_sql_delete_folder (priv->kdb,
+	                                        foldername,
+	                                        &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -737,11 +737,11 @@ kolab_mail_side_cache_store (KolabMailSideCache *self,
 
 	kconvmail = kolab_mail_handle_get_kconvmail (kmailhandle);
 
-	ok = kolab_mail_side_cache_sql_store_object (priv->kdb,
-	                                             kconvmail,
-	                                             kolab_uid,
-	                                             foldername,
-	                                             &tmp_err);
+	ok = mail_side_cache_sql_store_object (priv->kdb,
+	                                       kconvmail,
+	                                       kolab_uid,
+	                                       foldername,
+	                                       &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -788,10 +788,10 @@ kolab_mail_side_cache_retrieve (KolabMailSideCache *self,
 		return FALSE;
 	}
 
-	kconvmail = kolab_mail_side_cache_sql_query_object (priv->kdb,
-	                                                    kolab_uid,
-	                                                    foldername,
-	                                                    &tmp_err);
+	kconvmail = mail_side_cache_sql_query_object (priv->kdb,
+	                                              kolab_uid,
+	                                              foldername,
+	                                              &tmp_err);
 	if (tmp_err != NULL) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
@@ -831,10 +831,10 @@ kolab_mail_side_cache_delete_by_uid (KolabMailSideCache *self,
 
 	g_assert (priv->is_up == TRUE);
 
-	ok = kolab_mail_side_cache_sql_delete_by_uid (priv->kdb,
-	                                              uid,
-	                                              foldername,
-	                                              &tmp_err);
+	ok = mail_side_cache_sql_delete_by_uid (priv->kdb,
+	                                        uid,
+	                                        foldername,
+	                                        &tmp_err);
 	if (! ok) {
 		g_propagate_error (err, tmp_err);
 		return FALSE;
