@@ -335,8 +335,8 @@ mail_synchronizer_get_uidvalidity (KolabMailSynchronizer *self,
 	if (imap_uidvalidity > 0)
 		uidvalidity = imap_uidvalidity;
 
-	g_debug ("%s: InfoDb (%s) ImapClient (%s) UIDVALIDITY (%lld)",
-	         __func__, info_fn, imap_fn, uidvalidity);
+	g_debug ("%s: InfoDb (%s) ImapClient (%s) UIDVALIDITY (%ld)",
+	         __func__, info_fn, imap_fn, (long int) uidvalidity);
 
  skip:
 	if (tmp_err != NULL) {
@@ -1937,7 +1937,7 @@ kolab_mail_synchronizer_transaction_prepare (KolabMailSynchronizer *self,
 		can_act = FALSE;
 		goto cleanup;
 	}
-	
+
 	sync_id_ptr = kolab_settings_handler_get_value (priv->ksettings,
 	                                                KOLAB_SETTINGS_HANDLER_TBL_SYNCSTRATEGY,
 	                                                foldername,
@@ -2364,7 +2364,7 @@ kolab_mail_synchronizer_transaction_commit (KolabMailSynchronizer *self,
 	}
 
 	g_return_val_if_fail (record != NULL, FALSE);
-	
+
 	uid = kolab_mail_handle_get_uid (kmailhandle);
 
 	/* updates for store or push operations in online operation */
