@@ -33,9 +33,9 @@
 #include <glib.h>
 #include <gio/gio.h>
 
-#include <libebook/e-contact.h>
-#include <libecal/e-cal-component.h>
-#include <libedataserver/e-source.h>
+#include <libebook/libebook.h>
+#include <libecal/libecal.h>
+#include <libebackend/libebackend.h>
 
 #include <libekolabutil/camel-system-headers.h>
 #include <libekolabutil/kolab-util-sqlite.h>
@@ -73,28 +73,25 @@ typedef enum {
 GQuark kolab_util_backend_error_quark (void) G_GNUC_CONST;
 
 /*----------------------------------------------------------------------------*/
-/* calendar name <-> folder name translation */
-
-gchar* kolab_util_backend_sourcename_new_from_foldername (const gchar *foldername, GError **err);
-gchar* kolab_util_backend_foldername_new_from_sourcename (const gchar *sourcename, GError **err);
 
+const gchar *kolab_util_backend_get_foldername (EBackend *backend);
 gchar *kolab_util_backend_get_relative_path_from_uri (const gchar *uri);
 gchar *kolab_util_backend_get_protocol_from_uri (const gchar *uri);
 KolabSyncStrategyID kolab_util_misc_sync_value_from_property (const gchar *sync_prop);
 KolabTLSVariantID kolab_util_misc_tls_variant_from_property (const gchar *tls_variant);
+gint kolab_util_misc_port_number_from_property (const gchar *port_number_prop);
 KolabReqPkcs11 kolab_util_misc_req_pkcs11_from_property (const gchar *req_pkcs11_prop);
 void kolab_util_backend_koma_table_cleanup_cb (gpointer data, GObject *object, gboolean is_last_ref);
 
 void kolab_util_backend_modtime_set_on_econtact (EContact *econtact);
 void kolab_util_backend_modtime_set_on_ecalcomp (ECalComponent *ecalcomp);
-void kolab_util_backend_prepare_settings (KolabSettingsHandler *ksettings, ESource *esource, const gchar *servername, const gchar *username, const gchar *password, const gchar *sourcename, const KolabSyncStrategyID *sync_value);
+void kolab_util_backend_prepare_settings (KolabSettingsHandler *ksettings, ESource *esource, const gchar *password, const gchar *sourcename, const KolabSyncStrategyID *sync_value);
 
 gboolean kolab_util_backend_sqlite_db_new_open (KolabUtilSqliteDb **kdb, KolabSettingsHandler *ksettings, const gchar *dbfilename, GError **err);
 
 const gchar* kolab_util_backend_get_sync_strategy_desc (KolabSyncStrategyID id);
 const gchar* kolab_util_backend_get_tls_variant_desc (KolabTLSVariantID id);
 
-CamelURL* kolab_util_backend_camel_url_new_from_settings (KolabSettingsHandler *ksettings, GError **err);
 gchar* kolab_util_backend_account_uid_new_from_settings (KolabSettingsHandler *ksettings, GError **err);
 
 KolabMailAccessOpmodeID
