@@ -162,7 +162,7 @@ kolabconv_cal_util_freebusy_new_fb_url (const gchar *servername,
  */
 ECalComponent*
 kolabconv_cal_util_freebusy_ecalcomp_new_from_ics (const gchar *ics_string,
-                                                   gint nbytes,
+                                                   gssize nbytes,
                                                    GError **err)
 {
 	ECalComponent *ecalcomp = NULL;
